package pot.serverskeleton;

import java.io.*;
import java.net.*;

public class TextBasedChildServer extends SocketChildServer
  implements TextBasedInterface, PromptInterface
{
    BufferedReader br;
    PrintWriter pw;
    String prompt = "";

    public TextBasedChildServer(GenericParentServer gps, Socket s)
    {
        super(gps, s);
    }

    public void openStream() throws IOException
    {
	br = new BufferedReader
	    (new InputStreamReader(ss.getInputStream()));
	pw = new PrintWriter(ss.getOutputStream());
    }

    public void setPrompt(String s)
    {
	prompt = s;
    }
    
    public String getPrompt()
    {
	return  prompt;
    }

    public void putPrompt()
    {
	pw.print(prompt); pw.flush();
    }

    public void putLine(String line)
    {
	pw.println(line); pw.flush();
    }

    public void putString(String line)
    {
	pw.print(line); pw.flush();
    }

    public void pwClose()
    {
	pw.close();
    }

    public void pwReopen()
    {
    }

    public String getLine() throws IOException
    {
	return br.readLine();
    }

    public void disconnect() throws DisconnectionException
    {
	putLine("bye");
	super.disconnect();
    }

    public void handle(String command)
	throws IOException, DisconnectionException
    {
	putLine(command);
    }
    
    public void run()
    {
	String command;
	try
	{
	    openStream();
	    //putLine("Welcome to "+getClass()+".");
	    while(true)
		{
		    putPrompt();
		    command = getLine();
		    if (command == null || command.equals("bye"))
			disconnect();
		    else
			handle(command);
		}
	}
	catch(IOException e)
	{
		printLog(e);
	}
	catch(DisconnectionException e)
	{
		printLog(e);
	}
    }
}

